###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

        # Python script for Figures in following paper (c) by W. Yao, L. Puts, K. Williams and D. Lenstra
        # as part of the work published in "An All-Optical Spiking Laser Neuron Integrated in Generic 
        # InP Photonic Circuit Technology" published in Optics Express
        # 
        # This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
        # 
        # You should have received a copy of the license along with this work. If not, see 
        # <https://creativecommons.org/licenses/by-nc-sa/4.0/>.
        
        # Eindhoven Univesity of Technology, Eindhoven, the Netherlands, May 2025
        
        # Contact: l.puts@tue.nl

###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

import numpy as np
import matplotlib.pyplot as plt
from scipy.signal import find_peaks

plt.rcParams["font.family"] = 'Times New Roman'
plt.rcParams['font.size'] = 12

plt.rcParams['mathtext.default'] = 'regular'


color=['C0','C1','C2','C3','C4']
marker=['o','v','^','s','d']
markersize=5


folder_all=[
            "Sample h15b laser l3 excitability dual pulse timing measurement at 49.2012 mA -1.2000 V 2024-04-08_15_30_20",
            ]


delay=np.linspace(0,330,12)
delay=[0,180., 210., 240., 270., 300.,330.]

plt.close('all')

run_sweep=[1]

start_inp=80
end_inp=180

start_res=200
end_res=300

for i in range(len(folder_all)):
    folder=folder_all[i]
    
    # fig=plt.figure(i)
    fig, axs = plt.subplots(2,figsize=(4, 3))
    fig.patch.set_alpha(0)
    
    colors = plt.cm.inferno(np.linspace(0,1,len(delay)+1))
    
    data_inp_time=[]
    data_inp_sign=[]
    data_res_time=[]
    data_res_sign=[]

    for j in range(len(delay)):

        for k in range(len(run_sweep)):
            inp='Dual pulse delay '+str('{0:.4f}'.format(delay[j]))+' ps run '+str(run_sweep[k])+' input.npy'
            res='Dual pulse delay '+str('{0:.4f}'.format(delay[j]))+' ps run '+str(run_sweep[k])+' response.npy'
            
            data_inp=np.load(folder+'\\'+inp)
            data_res=np.load(folder+'\\'+res)
            
            data_inp_time=data_inp[0]
            data_inp_sign.extend(data_inp[1][start_inp:end_inp])
            data_res_sign.extend(data_res[1][start_res:end_res])
    
            time=np.linspace(0,len(data_inp_sign)*data_inp_time[1],len(data_inp_sign))*1e9
    
    inp_offset=0.23
    res_offset=0.23
    
    axs[0].plot(time,np.asarray(data_inp_sign)+inp_offset,'k',linewidth=0.7,alpha=1)
    axs[1].plot(time,np.asarray(data_res_sign)+res_offset,'k',linewidth=1.0,alpha=1)
    axs[0].set_ylabel('Inj. signal [V]', fontsize=10)
    axs[1].set_ylabel('Exc. signal [V]', fontsize=10)
    axs[1].set_xlabel('Time [ns]', fontsize=10)
    axs[0].grid()
    axs[1].grid()
    plt.tight_layout()